pub fn radix_decomposition(
input_space: usize,
min_space: usize,
max_space: usize,
) -> Vec<RadixDecomposition>Expand description
Computes possible radix decompositions
Takes the number of bit of the message space as input and output a vector containing all the correct possible block decomposition assuming the same message space for all blocks. Lower and upper bounds define the minimal and maximal space to be considered Example: 6,2,4 -> [ [2,3], [3,2]] : [msg_space = 2 bits, block_number = 3]
Example
use concrete_integer::client_key::radix_decomposition;
let input_space = 16; //
let min = 2;
let max = 4;
let decomp = radix_decomposition(input_space, min, max);
// Check that 3 possible radix decompositions are provided
assert_eq!(decomp.len(), 3);