Module server_key

Module server_key 

Module with the definition of the ServerKey.

This module implements the generation of the server public key, together with all the available homomorphic integer operations.

Structs

CrtMultiServerKey
ServerKey
A structure containing the server public key.

Enums

CheckError
Error returned when the carry buffer is full. Error returned when the carry buffer is full.