Module with the definition of the ServerKey.
This module implements the generation of the server public key, together with all the available homomorphic integer operations.
Structs
- CrtMulti
Server Key - Server
Key - A structure containing the server public key.
Enums
- Check
Error - Error returned when the carry buffer is full. Error returned when the carry buffer is full.